@@ -24,9 +24,13 @@ ARDUINO_TOOLCHAIN_CONFIG = "~/Library/Arduino15/arduino-cli.yaml"
 
 
 class ToolchainESP32Arduino_1_0_0(ToolChainBase):
-    def __init__(self):
+    def __init__(self, default_version):
         version_list = self.get_installed_toolchain_version()
 
+        # If not found, we default to the highest known version.
+        if not version_list:
+            version_list = default_version
+
         super(ToolchainESP32Arduino_1_0_0, self).__init__(
             "esp32arloc",
             "Espressif Esp32 Arduino Local",
@@ -282,15 +286,13 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
 
                     if not self._file_exists(ARDUINO_TOOLCHAIN_CONFIG):
                         if verbose:
-                            print(f"+ Arduino Toolchain config exists. Running init to create basic skeleton.")
+                            print(f"+ Arduino Toolchain config does not exist. Running init to create basic skeleton.")
 
                         cmd = f"{install_exe} config init --overwrite"
                         if verbose:
                             print(f" + Invoking: {cmd}")
                         self._exec(cmd)
 
-                    if verbose:
-                        print(f" + Invoking: {cmd}")
                     cmd = f"{install_exe} config set board_manager.additional_urls https://raw.githubusercontent.com/espressif/arduino-esp32/gh-pages/package_esp32_index.json"
                     if verbose:
                         print(f" + Exec: {cmd}")
@@ -366,6 +368,7 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
                 exit(1)
         except Exception as e:
             print(f"ERROR: Could not reset {install_exe}: {str(e)}")
+            traceback.print_exc()
             exit(1)
 
     #
@@ -407,7 +410,7 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
     # If the tool hasn't been installed yet, we just return "***".
     #
     def get_installed_toolchain_version(self, install_path=None):
-        result = "***"
+        result = None
         try:
             import glob
             tool_path = None
